@@ -644,7 +644,8 @@ mod tests {
         }
     }
 
-    /*#[test]
+    /*/
+    #[test]
     fn message_to_yaml() {
         let mut file_name = PathBuf::from(env!("CARGO_MANIFEST_DIR"));
         file_name.push("tests");
